package sk.codeblog.smsgateway;

import android.content.Context;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.net.Socket;

public class CommandThread extends  Thread{

    Context context;
    Socket socket;
    BufferedReader input = null;
    BufferedWriter output = null;

    public CommandThread(Context context, Socket socket)
    {
        this.context = context;
        this.socket = socket;
    }

    @Override
    public void run() {
        super.run();

        try {

            openStreams();

            String command = readFromSocket();

            if (command.startsWith("sms")) {
                String[] params = command.split(" ", 3);
                if (params.length == 3) {
                    String phoneNum = params[1];
                    String message = params[2];

                    if (!phoneNum.equals("") && !message.equals(""))
                    {
                        String clientIP = this.socket.getRemoteSocketAddress().toString();
                        Functions.sendInfoToApp(this.context , Constants.CALLBACK_TYPE_INFO, "SMS request from " + clientIP);
                        Functions.sendSMS(this.context, phoneNum, message, clientIP);
                        writeToSocket("0: Request accepted");
                    }
                    else
                    {
                        writeToSocket("3: Invalid parameter count");
                    }
                }
                else
                {
                    writeToSocket("2: Invalid parameter count");
                }
            }
            else
            {
                writeToSocket("1: Invalid command");
            }

        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            closeSocket();
        }

    }

    private void openStreams() throws IOException {
        input = new BufferedReader(new InputStreamReader(this.socket.getInputStream()));
        output = new BufferedWriter(new OutputStreamWriter(this.socket.getOutputStream()));
    }

    private void closeSocket() {
        try {
            if (input != null)
                input.close();
        } catch (Exception e) {
            e.printStackTrace();
        }

        try {
            if (output != null)
                output.close();
        } catch (Exception e) {
            e.printStackTrace();
        }

        try {
            this.socket.close();
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private String readFromSocket() throws IOException {
        return input.readLine();
    }

    private void writeToSocket(String Message) throws IOException {
        output.write(Message + "\n");
        output.flush();
    }
}
